@@ -24,6 +24,8 @@ pub enum InputIteratorErr {
 /// The error type for the argument module.
 #[derive(Debug)]
 pub enum ParseErr {
+    DelayNaN(usize),
+    DelayNoValue,
     /// An error occurred with accessing the unprocessed file.
     File(FileErr),
     /// The value of jobs was not set to a number.
@@ -36,8 +38,12 @@ pub enum ParseErr {
     MaxArgsNaN(usize),
     /// No value was provided for the `max_args` flag.
     MaxArgsNoValue,
+    MemInvalid(usize),
+    MemNoValue,
     /// No arguments were given, so no action can be taken.
     NoArguments,
+    TimeoutNaN(usize),
+    TimeoutNoValue,
 }
 
 impl From<FileErr> for ParseErr {
@@ -79,6 +85,12 @@ impl ParseErr {
                     let _ = write!(stderr, "unable to write to file: {:?}: {}\n", file, why);
                 },
             },
+            ParseErr::DelayNaN(index) => {
+                let _ = write!(stderr, "delay parameter, '{}', is not a number.\n", arguments[index]);
+            },
+            ParseErr::DelayNoValue => {
+                let _ = stderr.write(b"no delay parameter was defined.\n");
+            },
             ParseErr::JobsNaN(value) => {
                 let _ = write!(stderr, "jobs parameter, '{}', is not a number.\n", value);
             },
@@ -90,12 +102,24 @@ impl ParseErr {
             },
             ParseErr::MaxArgsNoValue => {
                 let _ = stderr.write(b"no groups parameter was defined.\n");
+            },
+            ParseErr::MemNoValue => {
+                let _ = stderr.write(b"no memory parameter was defined.\n");
+            },
+            ParseErr::MemInvalid(index) => {
+                let _ = write!(stderr, "invalid memory value: {}\n", arguments[index]);
             }
             ParseErr::InvalidArgument(index) => {
                 let _ = write!(stderr, "invalid argument: {}\n", arguments[index]);
             },
             ParseErr::NoArguments => {
                 let _ = write!(stderr, "no input arguments were given.\n");
+            },
+            ParseErr::TimeoutNaN(index) => {
+                let _ = write!(stderr, "invalid timeout value: {}\n", arguments[index]);
+            },
+            ParseErr::TimeoutNoValue => {
+                let _ = stderr.write(b"no timeout parameter was defined.\n");
             }
         };
         let _ = stdout.write(b"For help on command-line usage, execute `parallel -h`\n");
