@@ -77,11 +77,23 @@ OPTIONS
     Options may also be supplied to the program to change how the program
     operates:
 
+    --delay:
+        Delays starting the next job for N amount of seconds, where the seconds can be fractional.
+
+    --dry-run:
+        Prints the jobs that will be run to standard output, without running them.
+
+    --eta:
+        Prints the estimated time to complete based on average runtime of running processes.
+
     -j, --jobs:
         Defines the number of tasks to process in parallel.
         Values may be written as a number (12) or as a percent (150%).
         The default value is the number of CPU cores in the system.
 
+    --memfree:
+        Defines the minimum amount of memory available before starting the next job.
+
     -n, --max-args:
         Groups up to a certain number of arguments together in the same
         command line. For example, if five arguments are supplied and max
@@ -89,10 +101,12 @@ OPTIONS
         first argument, arguments three and four will become the second
         argument, and argument five will become the third argument.
 
+    --num-cpu-cores:
+        A convenience command that will print the number of CPU cores in the system.
+
     -p, --pipe:
-        Instead of supplying arguments as arguments to child processes,
-        instead supply the arguments directly to the standard input of each
-        child process.
+        Instead of supplying arguments as arguments to child processes, apply
+        them to the standard input of each child process.
 
     -q, --quote:
         Retains backslashes that are supplied as the command input.
@@ -100,6 +114,14 @@ OPTIONS
     -s, --silent, --quiet:
         Disables printing the standard output of running processes.
 
+    --shebang:
+        Grants ability to utilize the parallel command as an interpreter via
+        calling it within a shebang line.
+
+    --timeout:
+        If a command runs for longer than a specified number of seconds, it will be
+        killed with a SIGKILL.
+
     --shellquote:
         Expands upon quote mode by escaping a wide variety of special characters.
 
@@ -109,10 +131,6 @@ OPTIONS
     --version:
         Print version information.
 
-    --num-cpu-cores:
-        A convenience command that will print the number of CPU cores in the
-        system.
-
 EXAMPLES
     # Command followed by inputs
     parallel -vun 'ffmpeg -i "{}" -c:a libopus -b:a 128k "{.}.opus"' ::: $(find -type f -name "*.flac")
@@ -129,6 +147,11 @@ EXAMPLES
     # Reading inputs from files and command arguments
     parallel 'echo {}' :::: list1 list2 ::: $(seq 1 10) :::: list3 list4
 
+    # Within a file, with each successive newline being an input argument
+    #!/usr/bin/parallel --shebang echo
+    1
+    2
+
 HOW IT WORKS
     The Parallel command consists of three phases: parsing, threading, and execution.
 
